#

    	heredity

    		# heredity

    		# braiding

    		# generator
    			# loom
    			# sequencer
    			# replicase
    			# pairing
    			# synthesizer
    			# twister
    			# helixifier
    			# https://en.wikipedia.org/wiki/Polymerase
    				# enzyme

    		# Syzygy
    			# https://en.wikipedia.org/wiki/Synapsis

    			# genetic reshuffling, recombination, combination, splicing
    				# https://en.wikipedia.org/wiki/Genetic_recombination

    			# Synaptonemal complex
    				https://en.wikipedia.org/wiki/Synaptonemal_complex

    		# synaptonemal complex
    			# chiasmata
    				# https://en.wikipedia.org/wiki/Chiasma_(genetics)

    			# chromosomal crossover, genetic exchange
    				# https://en.wikipedia.org/wiki/Chromosomal_crossover

    			# Syzygy
    				# https://en.wikipedia.org/wiki/Synapsis

    		# venue
    			# multiverse, multimotto, song, album, conference

    		# fertilization
    			# genome modifications

    			# gamete cytecore merger

    		# Homologous Recombination
    			# https://en.wikipedia.org/wiki/Homologous_recombination

    			https://en.wikipedia.org/wiki/Meiosis#/media/File:Synaptonemal_Complex.svg

    		# meiosis
    			# splicing

    			# zygote, blastocyst, embryo, baby
    				# genetic combinations
    				# fertilization

    				# gamete fusion
    					# haploid oocyte (egg) + spermatozoa (sperm) = zygote
    						# fallopian tube

    					# gamete + gamete = zygote

    				# MZT
    					# https://en.wikipedia.org/wiki/Maternal_to_zygotic_transition
    					# https://en.wikipedia.org/wiki/Codon_usage_bias

    				# zygote
    					A diploid that contains every chromosome

    			# cytecore mergers
    				# cytecore membrane merger

    				# syncytia

    				# chromosome mergers
    					# genetic recombination, crossing over

    						# prophase I of meiosis:
    							https://en.wikipedia.org/wiki/Meiosis#Prophase_I

    							# synapse
    								https://en.wikipedia.org/wiki/Homologous_recombination

    						# Genetic Exchange
    							sequences are exchanged between chromatids
    							https://en.wikipedia.org/wiki/Chromatid

    			# https://en.wikipedia.org/wiki/Horizontal_gene_transfer

    		# social

    		# family
    		# ohana
    		# umndeni

    		# fabricator

    		# polymerase
    			# https://en.wikipedia.org/wiki/Polymerase